//
// ********************************************************************
// * DISCLAIMER                                                       *
// *                                                                  *
// * The following disclaimer summarizes all the specific disclaimers *
// * of contributors to this software. The specific disclaimers,which *
// * govern, are listed with their locations in:                      *
// *   http://cern.ch/geant4/license                                  *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.                                                             *
// *                                                                  *
// * This  code  implementation is the  intellectual property  of the *
// * GEANT4 collaboration.                                            *
// * By copying,  distributing  or modifying the Program (or any work *
// * based  on  the Program)  you indicate  your  acceptance of  this *
// * statement, and all its terms.                                    *
// ********************************************************************
//
//
// Implementation of the HETC88 code into Geant4.
// Evaporation and De-excitation parts
// T. Lampen, Helsinki Institute of Physics, May-2000

#include "G4BEHe3Channel.hh"
#include "G4He3.hh"

G4BEHe3Channel::G4BEHe3Channel()
{
  name = "He3";
    verboseLevel = 0;
    particleA = 3;
    particleZ = 2;
    rho = 0.70588;
    A=3;
    spin = 0.5;
}


G4BEHe3Channel::~G4BEHe3Channel()
{
}


G4DynamicParticle*  G4BEHe3Channel::emit()
{
  G4double u , v , w;
  G4DynamicParticle * pParticle = new G4DynamicParticle;
  pParticle -> SetDefinition( G4He3::He3() );
  pParticle -> SetKineticEnergy( sampleKineticEnergy() ); 
  isotropicCosines( u, v, w);
  pParticle -> SetMomentumDirection( u, v, w);  
  return pParticle;
}


G4double G4BEHe3Channel::coulombFactor()
{
  return 0;
}


G4double G4BEHe3Channel::qmFactor()
{
  // Coefficient representing the quantum mechanical barrier
  // penetration, see Dostrovsky, Phys. Rev. 116, 1959.
  return qmFactorForAlpha() - 0.06;
}
